/*
DL2 Monitor: ./pa/pa.h
Copyright (C) 2002, Rolf Jger, Ulm (Germany)

See the file README for information on usage and redistribution
of this source code file, and for a DISCLAIMER OF ALL WARRANTIES.
*/

/*----------------------------------------------------------------------------
 * Datalink Monitor (pa): Packet Analyzer Definitions (local)
 *
 * These definitions are subject to implementation dependent properties of
 * the dl2pa module. Therefore, the header shouldn't be included otherwise
 * than by subsequent modules which are concerned with certain packet types.
 * The dl2pa module needs internal packet type identification, configuration
 * names, and others. The rule is:
 *   modules define their requirementsi on field selections;
 *   dl2pa provides for the actual settings (pa_verbose)
 * 
 * PA_DL2MONRC	basename of the configuration file
 * PA_PID_*	internal packet type identifiers, usable as array indexes;
 * Pa_Packet	packet type relevant information:
 *   name	of the packet type as being used in .dl2monrc,
 *   field	list of field specific configurations;
 * Pa_Config	field configuration per packet type:
 *   cname	of the field as being used in .dl2monrc,
 *   oname	of the field as it appears in output (NULL=end of list),
 *   index	ranging from 0..31;
 * PA_VM*	reserved verbose flags: default, packet_length,...
 *		generally, bits 31..28 are considered reserved. 
 *
 * Introducing a new packet type pt means to allocate the next PA_PID_ index,
 * to supply for a module pt.h which creates the Pa_Packet object pa_pt, and
 * to add an extern declaration for this object. Of course, the must exist 
 * an implementation module (papt.c) too. Currently, the pt's ether2, pppoed, 
 * icmp, tcp, upd, and ip have been implemented.
 *
 * -pa_verbose(i)
 *  the function returns the field selection settings to the PA_PID_ i,
 *  which are currently in effect.
 *
 * Author: Rolf Jger,Ulm
 *----------------------------------------------------------------------------
 * YYYYMMDD  History
 * 20020410  PA_VM_*: reserved verbose flags introduced.
 * 20020330  created from scratch
 * $Id: pa.h,v 1.4 2002/04/10 10:36:26 dv Exp $
 *----------------------------------------------------------------------------
*/
# ifndef __PA_H__
# define __PA_H__

# define PA_DL2MONRC	".dl2monrc"
# define PA_FC_UNKNOWN	"?code"
# define PA_FT_UNKNOWN	"?type"

# define PA_PID_ether2	0
# define PA_PID_pppoe	1
# define PA_PID_lcp	2	
# define PA_PID_ipcp	3	
# define PA_PID_pap	4	
# define PA_PID_chap	5	
# define PA_PID_lqr	6	
# define PA_PID_ctcp	7	
# define PA_PID_utcp	8	
# define PA_PID_icmp	9
# define PA_PID_tcp	10
# define PA_PID_udp	11
# define PA_PID_ip	12
# define PA_N_PTYPES	(PA_PID_ip+1)

# define PA_VMdefault		0x80000000
# define PA_VMpacket_length	0x40000000
# define PA_VFpacket_length	"PL"

typedef struct Pa_Packet {
  const char *name;
  struct Pa_Config *field;
} Pa_Packet;

typedef struct Pa_Config {
  const char *cname;
  const char *oname;
  int index;
} Pa_Config;

extern int pa_verbose(int);
extern const Pa_Packet pa_ether2;
extern const Pa_Packet pa_pppoe;
extern const Pa_Packet pa_lcp;
extern const Pa_Packet pa_ipcp;
extern const Pa_Packet pa_pap;
extern const Pa_Packet pa_chap;
extern const Pa_Packet pa_lqr;
extern const Pa_Packet pa_ctcp;
extern const Pa_Packet pa_utcp;
extern const Pa_Packet pa_icmp;
extern const Pa_Packet pa_tcp;
extern const Pa_Packet pa_udp;
extern const Pa_Packet pa_ip;

# endif /*__PA_H__*/
